<?php

return [
    'Names' => [
        'aa' => 'अफ़ार',
        'ab' => 'अब्ख़ाज़ियन',
        'ace' => 'अचाइनीस',
        'ach' => 'अकोली',
        'ada' => 'अदान्गमे',
        'ady' => 'अदिघे',
        'ae' => 'अवस्ताई',
        'af' => 'अफ़्रीकी',
        'afh' => 'अफ्रिहिली',
        'agq' => 'अग्हेम',
        'ain' => 'ऐनू',
        'ak' => 'अकन',
        'akk' => 'अक्कादी',
        'ale' => 'अलेउत',
        'alt' => 'दक्षिणी अल्ताई',
        'am' => 'अम्हेरी',
        'an' => 'अर्गोनी',
        'ang' => 'पुरानी अंग्रेज़ी',
        'ann' => 'ओबोलो',
        'anp' => 'अंगिका',
        'ar' => 'अरबी',
        'arc' => 'ऐरेमेक',
        'arn' => 'मापूचे',
        'arp' => 'अरापाहो',
        'ars' => 'नज्दी अरबी',
        'arw' => 'अरावक',
        'as' => 'असमिया',
        'asa' => 'असु',
        'ast' => 'अस्तुरियन',
        'atj' => 'अतिकामेक्व',
        'av' => 'अवेरिक',
        'awa' => 'अवधी',
        'ay' => 'आयमारा',
        'az' => 'अज़रबैजानी',
        'ba' => 'बशख़िर',
        'bal' => 'बलूची',
        'ban' => 'बालिनीस',
        'bas' => 'बसा',
        'be' => 'बेलारूसी',
        'bej' => 'बेजा',
        'bem' => 'बेम्बा',
        'bez' => 'बेना',
        'bg' => 'बुल्गारियाई',
        'bgn' => 'पश्चिमी बलोची',
        'bho' => 'भोजपुरी',
        'bi' => 'बिस्लामा',
        'bik' => 'बिकोल',
        'bin' => 'बिनी',
        'bla' => 'सिक्सिका',
        'bm' => 'बाम्बारा',
        'bn' => 'बंगाली',
        'bo' => 'तिब्बती',
        'br' => 'ब्रेटन',
        'bra' => 'ब्रज',
        'brx' => 'बोडो',
        'bs' => 'बोस्नियाई',
        'bua' => 'बुरियात',
        'bug' => 'बगिनीस',
        'byn' => 'ब्लिन',
        'ca' => 'कातालान',
        'cad' => 'कैड्डो',
        'car' => 'कैरिब',
        'cay' => 'कायुगा',
        'cch' => 'अत्सम',
        'ccp' => 'चकमा',
        'ce' => 'चेचन',
        'ceb' => 'सिबुआनो',
        'cgg' => 'शिगा',
        'ch' => 'कमोरो',
        'chb' => 'चिब्चा',
        'chg' => 'छगाताई',
        'chk' => 'चूकीस',
        'chm' => 'मारी',
        'chn' => 'चिनूक जारगॉन',
        'cho' => 'चोक्तौ',
        'chp' => 'शिपेव्यान',
        'chr' => 'चेरोकी',
        'chy' => 'शेयेन्न',
        'ckb' => 'सोरानी कुर्दिश',
        'clc' => 'चिलकोटिन',
        'co' => 'कोर्सीकन',
        'cop' => 'कॉप्टिक',
        'cr' => 'क्री',
        'crg' => 'मिचिफ़',
        'crh' => 'क्रीमीन तुर्की',
        'crj' => 'दक्षिण पूर्वी क्री',
        'crk' => 'प्लेन्स क्री',
        'crl' => 'नॉर्दन ईस्ट क्री',
        'crm' => 'मूस क्री',
        'crr' => 'कैरोलाइना एल्गोंक्वीयन',
        'crs' => 'सेसेल्वा क्रिओल फ्रेंच',
        'cs' => 'चेक',
        'csb' => 'काशुबियन',
        'csw' => 'स्वॉम्पी क्री',
        'cu' => 'चर्च साल्विक',
        'cv' => 'चूवाश',
        'cy' => 'वेल्श',
        'da' => 'डेनिश',
        'dak' => 'दाकोता',
        'dar' => 'दार्गवा',
        'dav' => 'तैता',
        'de' => 'जर्मन',
        'del' => 'डिलैवेयर',
        'den' => 'स्लेव',
        'dgr' => 'डोग्रिब',
        'din' => 'दिन्का',
        'dje' => 'झार्मा',
        'doi' => 'डोगरी',
        'dsb' => 'निचला सॉर्बियन',
        'dua' => 'दुआला',
        'dum' => 'मध्यकालीन पुर्तगाली',
        'dv' => 'दिवेही',
        'dyo' => 'जोला-फोंई',
        'dyu' => 'ड्युला',
        'dz' => 'ज़ोन्गखा',
        'dzg' => 'दज़ागा',
        'ebu' => 'एम्बु',
        'ee' => 'ईवे',
        'efi' => 'एफिक',
        'egy' => 'प्राचीन मिस्री',
        'eka' => 'एकाजुक',
        'el' => 'यूनानी',
        'elx' => 'एलामाइट',
        'en' => 'अंग्रेज़ी',
        'enm' => 'मध्यकालीन अंग्रेज़ी',
        'eo' => 'एस्पेरेंतो',
        'es' => 'स्पेनिश',
        'et' => 'एस्टोनियाई',
        'eu' => 'बास्क',
        'ewo' => 'इवोन्डो',
        'fa' => 'फ़ारसी',
        'fan' => 'फैन्ग',
        'fat' => 'फन्टी',
        'ff' => 'फुलाह',
        'fi' => 'फ़िनिश',
        'fil' => 'फ़िलिपीनो',
        'fj' => 'फिजियन',
        'fo' => 'फ़ैरोइज़',
        'fon' => 'फॉन',
        'fr' => 'फ़्रेंच',
        'frc' => 'केजन फ़्रेंच',
        'frm' => 'मध्यकालीन फ़्रांसीसी',
        'fro' => 'पुरातन फ़्रांसीसी',
        'frr' => 'उत्तरी फ़्रीसियाई',
        'frs' => 'पूर्वी फ़्रीसियाई',
        'fur' => 'फ्रीयुलीयान',
        'fy' => 'पश्चिमी फ़्रिसियाई',
        'ga' => 'आयरिश',
        'gaa' => 'गा',
        'gag' => 'गागौज़',
        'gay' => 'गायो',
        'gba' => 'ग्बाया',
        'gd' => 'स्कॉटिश गाएलिक',
        'gez' => 'गीज़',
        'gil' => 'गिल्बरतीस',
        'gl' => 'गैलिशियन',
        'gmh' => 'मध्यकालीन हाइ जर्मन',
        'gn' => 'गुआरानी',
        'goh' => 'पुरातन हाइ जर्मन',
        'gon' => 'गाँडी',
        'gor' => 'गोरोन्तालो',
        'got' => 'गॉथिक',
        'grb' => 'ग्रेबो',
        'grc' => 'प्राचीन यूनानी',
        'gsw' => 'स्विस जर्मन',
        'gu' => 'गुजराती',
        'guz' => 'गुसी',
        'gv' => 'मैंक्स',
        'gwi' => 'ग्विचइन',
        'ha' => 'हौसा',
        'hai' => 'हैडा',
        'haw' => 'हवाई',
        'hax' => 'दक्षिणी हाइदा',
        'he' => 'हिब्रू',
        'hi' => 'हिन्दी',
        'hil' => 'हिलिगेनन',
        'hit' => 'हिताइत',
        'hmn' => 'ह्मॉंग',
        'ho' => 'हिरी मोटू',
        'hr' => 'क्रोएशियाई',
        'hsb' => 'ऊपरी सॉर्बियन',
        'ht' => 'हैतियाई',
        'hu' => 'हंगेरियाई',
        'hup' => 'हूपा',
        'hur' => 'हल्कोमेलम',
        'hy' => 'आर्मेनियाई',
        'hz' => 'हरैरो',
        'ia' => 'इंटरलिंगुआ',
        'iba' => 'इबान',
        'ibb' => 'इबिबियो',
        'id' => 'इंडोनेशियाई',
        'ie' => 'ईन्टरलिंगुइ',
        'ig' => 'ईग्बो',
        'ii' => 'सिचुआन यी',
        'ik' => 'इनुपियाक्',
        'ikt' => 'पश्चिमी कनाडाई इनुक्टिटुट',
        'ilo' => 'इलोको',
        'inh' => 'इंगुश',
        'io' => 'इडौ',
        'is' => 'आइसलैंडिक',
        'it' => 'इतालवी',
        'iu' => 'इनुक्टिटुट',
        'ja' => 'जापानी',
        'jbo' => 'लोज्बान',
        'jgo' => 'नगोंबा',
        'jmc' => 'मैकहैमे',
        'jpr' => 'जुदेओ-पर्शियन',
        'jrb' => 'जुदेओ-अरेबिक',
        'jv' => 'जावानीज़',
        'ka' => 'जॉर्जियाई',
        'kaa' => 'कारा-कल्पक',
        'kab' => 'कबाइल',
        'kac' => 'काचिन',
        'kaj' => 'ज्जु',
        'kam' => 'कम्बा',
        'kaw' => 'कावी',
        'kbd' => 'कबार्डियन',
        'kcg' => 'त्याप',
        'kde' => 'मैकोंड',
        'kea' => 'काबुवेर्दियानु',
        'kfo' => 'कोरो',
        'kg' => 'कोंगो',
        'kgp' => 'काइंगांग',
        'kha' => 'खासी',
        'kho' => 'खोतानीस',
        'khq' => 'कोयरा चीनी',
        'ki' => 'किकुयू',
        'kj' => 'क्वान्यामा',
        'kk' => 'कज़ाख़',
        'kkj' => 'काको',
        'kl' => 'कलालीसुत',
        'kln' => 'कलेंजिन',
        'km' => 'खमेर',
        'kmb' => 'किम्बन्दु',
        'kn' => 'कन्नड़',
        'ko' => 'कोरियाई',
        'koi' => 'कोमी-पर्मयाक',
        'kok' => 'कोंकणी',
        'kos' => 'कोसरैन',
        'kpe' => 'क्पेल',
        'kr' => 'कनुरी',
        'krc' => 'कराचय-बल्कार',
        'krl' => 'करेलियन',
        'kru' => 'कुरूख',
        'ks' => 'कश्मीरी',
        'ksb' => 'शम्बाला',
        'ksf' => 'बफिआ',
        'ksh' => 'कोलोनियाई',
        'ku' => 'कुर्दिश',
        'kum' => 'कुमीक',
        'kut' => 'क्यूतनाई',
        'kv' => 'कोमी',
        'kw' => 'कोर्निश',
        'kwk' => 'क्वॉकवाला',
        'ky' => 'किर्गीज़',
        'la' => 'लैटिन',
        'lad' => 'लादीनो',
        'lag' => 'लांगि',
        'lah' => 'लाह्न्डा',
        'lam' => 'लाम्बा',
        'lb' => 'लग्ज़मबर्गी',
        'lez' => 'लेज़्घीयन',
        'lg' => 'गांडा',
        'li' => 'लिंबर्गिश',
        'lil' => 'लिलोएट',
        'lkt' => 'लैकोटा',
        'lmo' => 'लॉमबर्ड',
        'ln' => 'लिंगाला',
        'lo' => 'लाओ',
        'lol' => 'मोंगो',
        'lou' => 'लुईज़ियाना क्रियोल',
        'loz' => 'लोज़ी',
        'lrc' => 'उत्तरी लूरी',
        'lsm' => 'सामिया',
        'lt' => 'लिथुआनियाई',
        'lu' => 'ल्यूबा-कटांगा',
        'lua' => 'ल्यूबा-लुलुआ',
        'lui' => 'लुइसेनो',
        'lun' => 'लुन्डा',
        'luo' => 'ल्युओ',
        'lus' => 'मिज़ो',
        'luy' => 'ल्युईआ',
        'lv' => 'लातवियाई',
        'mad' => 'मादुरीस',
        'mag' => 'मगही',
        'mai' => 'मैथिली',
        'mak' => 'मकासर',
        'man' => 'मन्डिन्गो',
        'mas' => 'मसाई',
        'mdf' => 'मोक्ष',
        'mdr' => 'मंदार',
        'men' => 'मेन्डे',
        'mer' => 'मेरु',
        'mfe' => 'मोरीस्येन',
        'mg' => 'मालागासी',
        'mga' => 'मध्यकालीन आइरिश',
        'mgh' => 'मैखुवा-मीट्टो',
        'mgo' => 'मेटा',
        'mh' => 'मार्शलीज़',
        'mi' => 'माओरी',
        'mic' => 'मिकमैक',
        'min' => 'मिनांग्काबाउ',
        'mk' => 'मकदूनियाई',
        'ml' => 'मलयालम',
        'mn' => 'मंगोलियाई',
        'mnc' => 'मन्चु',
        'mni' => 'मणिपुरी',
        'moe' => 'इन्नु-एईमन',
        'moh' => 'मोहौक',
        'mos' => 'मोस्सी',
        'mr' => 'मराठी',
        'ms' => 'मलय',
        'mt' => 'माल्टीज़',
        'mua' => 'मुंडैंग',
        'mus' => 'क्रीक',
        'mwl' => 'मिरांडी',
        'mwr' => 'मारवाड़ी',
        'my' => 'बर्मीज़',
        'myv' => 'एर्ज़या',
        'mzn' => 'माज़न्देरानी',
        'na' => 'नाउरू',
        'nan' => 'मिन नान',
        'nap' => 'नीपोलिटन',
        'naq' => 'नामा',
        'nb' => 'नॉर्वेजियाई बोकमाल',
        'nd' => 'उत्तरी देबेल',
        'nds' => 'निचला जर्मन',
        'ne' => 'नेपाली',
        'new' => 'नेवाड़ी',
        'ng' => 'डोन्गा',
        'nia' => 'नियास',
        'niu' => 'नियुआन',
        'nl' => 'डच',
        'nmg' => 'क्वासिओ',
        'nn' => 'नॉर्वेजियाई नॉयनॉर्स्क',
        'nnh' => 'गैम्बू',
        'no' => 'नॉर्वेजियाई',
        'nog' => 'नोगाई',
        'non' => 'पुराना नॉर्स',
        'nqo' => 'एन्को',
        'nr' => 'दक्षिण देबेल',
        'nso' => 'उत्तरी सोथो',
        'nus' => 'नुएर',
        'nv' => 'नावाजो',
        'nwc' => 'पारम्परिक नेवारी',
        'ny' => 'न्यानजा',
        'nym' => 'न्यामवेज़ी',
        'nyn' => 'न्यानकोल',
        'nyo' => 'न्योरो',
        'nzi' => 'न्ज़ीमा',
        'oc' => 'ओसीटान',
        'oj' => 'ओजिब्वा',
        'ojb' => 'उत्तरपश्चिमी ओजिब्वे',
        'ojc' => 'सेंट्रल ओजीब्वे',
        'ojs' => 'ओजी-क्री',
        'ojw' => 'पश्चिमी ओजिब्वा',
        'oka' => 'ओकनागन',
        'om' => 'ओरोमो',
        'or' => 'ओड़िया',
        'os' => 'ओस्सेटिक',
        'osa' => 'ओसेज',
        'ota' => 'ओटोमान तुर्किश',
        'pa' => 'पंजाबी',
        'pag' => 'पंगासीनान',
        'pal' => 'पाह्लावी',
        'pam' => 'पाम्पान्गा',
        'pap' => 'पापियामेन्टो',
        'pau' => 'पलोउआन',
        'pcm' => 'नाइजीरियाई पिडगिन',
        'peo' => 'पुरानी फारसी',
        'phn' => 'फोएनिशियन',
        'pi' => 'पाली',
        'pis' => 'पाईजिन',
        'pl' => 'पोलिश',
        'pon' => 'पोह्नपिएन',
        'pqm' => 'मलेसीट-पासेमेक्वोडी',
        'prg' => 'प्रुशियाई',
        'pro' => 'पुरानी प्रोवेन्सल',
        'ps' => 'पश्तो',
        'pt' => 'पुर्तगाली',
        'qu' => 'क्वेचुआ',
        'quc' => 'किश',
        'raj' => 'राजस्थानी',
        'rap' => 'रापानुई',
        'rar' => 'रारोतोंगन',
        'rhg' => 'रोहिंग्या',
        'rm' => 'रोमान्श',
        'rn' => 'रुन्दी',
        'ro' => 'रोमानियाई',
        'rof' => 'रोम्बो',
        'rom' => 'रोमानी',
        'ru' => 'रूसी',
        'rup' => 'अरोमानियन',
        'rw' => 'किन्यारवांडा',
        'rwk' => 'रवा',
        'sa' => 'संस्कृत',
        'sad' => 'सन्डावे',
        'sah' => 'याकूत',
        'sam' => 'सामैरिटन अरैमिक',
        'saq' => 'सैम्बुरु',
        'sas' => 'सासाक',
        'sat' => 'संथाली',
        'sba' => 'न्गाम्बे',
        'sbp' => 'सैंगु',
        'sc' => 'सार्दिनियन',
        'scn' => 'सिसिलियन',
        'sco' => 'स्कॉट्स',
        'sd' => 'सिंधी',
        'sdh' => 'दक्षिणी कार्डिश',
        'se' => 'नॉर्दन सामी',
        'seh' => 'सेना',
        'sel' => 'सेल्कप',
        'ses' => 'कोयराबोरो सेन्नी',
        'sg' => 'सांगो',
        'sga' => 'पुरानी आइरिश',
        'sh' => 'सेर्बो-क्रोएशियाई',
        'shi' => 'तैचेल्हित',
        'shn' => 'शैन',
        'si' => 'सिंहली',
        'sid' => 'सिदामो',
        'sk' => 'स्लोवाक',
        'sl' => 'स्लोवेनियाई',
        'slh' => 'दक्षिणी लशूटसीड',
        'sm' => 'सामोन',
        'sma' => 'दक्षिणी सामी',
        'smj' => 'ल्युल सामी',
        'smn' => 'इनारी सामी',
        'sms' => 'स्कोल्ट सामी',
        'sn' => 'शोणा',
        'snk' => 'सोनिन्के',
        'so' => 'सोमाली',
        'sog' => 'सोग्डिएन',
        'sq' => 'अल्बानियाई',
        'sr' => 'सर्बियाई',
        'srn' => 'स्रानान टॉन्गो',
        'srr' => 'सेरेर',
        'ss' => 'स्वाती',
        'ssy' => 'साहो',
        'st' => 'दक्षिणी सेसेथो',
        'str' => 'स्ट्रेट्स सैलिश',
        'su' => 'सुंडानी',
        'suk' => 'सुकुमा',
        'sus' => 'सुसु',
        'sux' => 'सुमेरियन',
        'sv' => 'स्वीडिश',
        'sw' => 'स्वाहिली',
        'swb' => 'कोमोरियन',
        'syc' => 'क्लासिकल सिरिएक',
        'syr' => 'सिरिएक',
        'ta' => 'तमिल',
        'tce' => 'दक्षिणी टशोनी',
        'te' => 'तेलुगू',
        'tem' => 'टिम्ने',
        'teo' => 'टेसो',
        'ter' => 'तेरेनो',
        'tet' => 'तेतुम',
        'tg' => 'ताजिक',
        'tgx' => 'टैगिश',
        'th' => 'थाई',
        'tht' => 'टैल्हटन',
        'ti' => 'तिग्रीन्या',
        'tig' => 'टाइग्रे',
        'tiv' => 'तिव',
        'tk' => 'तुर्कमेन',
        'tkl' => 'तोकेलाऊ',
        'tl' => 'टैगलॉग',
        'tlh' => 'क्लिंगन',
        'tli' => 'त्लिंगित',
        'tmh' => 'तामाशेक',
        'tn' => 'सेत्स्वाना',
        'to' => 'टोंगन',
        'tog' => 'न्यासा टोन्गा',
        'tok' => 'टोकी पोना',
        'tpi' => 'टोक पिसिन',
        'tr' => 'तुर्की',
        'trv' => 'तारोको',
        'ts' => 'सोंगा',
        'tsi' => 'त्सिमीशियन',
        'tt' => 'तातार',
        'ttm' => 'उत्तरी टुशोनी',
        'tum' => 'तम्बूका',
        'tvl' => 'तुवालु',
        'tw' => 'ट्वी',
        'twq' => 'टासवाक',
        'ty' => 'ताहितियन',
        'tyv' => 'तुवीनियन',
        'tzm' => 'मध्य एटलस तमाज़ित',
        'udm' => 'उदमुर्त',
        'ug' => 'उइगर',
        'uga' => 'युगैरिटिक',
        'uk' => 'यूक्रेनियाई',
        'umb' => 'उम्बुन्डु',
        'ur' => 'उर्दू',
        'uz' => 'उज़्बेक',
        'vai' => 'वाई',
        've' => 'वेन्दा',
        'vi' => 'वियतनामी',
        'vo' => 'वोलापुक',
        'vot' => 'वॉटिक',
        'vun' => 'वुंजो',
        'wa' => 'वाल्लून',
        'wae' => 'वाल्सर',
        'wal' => 'वलामो',
        'war' => 'वारै',
        'was' => 'वाशो',
        'wbp' => 'वॉल्पेरी',
        'wo' => 'वोलोफ़',
        'wuu' => 'वू चीनी',
        'xal' => 'काल्मिक',
        'xh' => 'ख़ोसा',
        'xog' => 'सोगा',
        'yao' => 'याओ',
        'yap' => 'यापीस',
        'yav' => 'यांगबेन',
        'ybb' => 'येंबा',
        'yi' => 'यहूदी',
        'yo' => 'योरूबा',
        'yrl' => 'नेइंगातू',
        'yue' => 'कैंटोनीज़',
        'za' => 'ज़ुआंग',
        'zap' => 'ज़ेपोटेक',
        'zbl' => 'ब्लिसिम्बॉल्स',
        'zen' => 'ज़ेनान्गा',
        'zgh' => 'मानक मोरक्कन तामाज़ाइट',
        'zh' => 'चीनी',
        'zu' => 'ज़ुलू',
        'zun' => 'ज़ूनी',
        'zza' => 'ज़ाज़ा',
    ],
    'LocalizedNames' => [
        'ar_001' => 'आधुनिक मानक अरबी',
        'de_AT' => 'ऑस्ट्रियाई जर्मन',
        'de_CH' => 'स्विस उच्च जर्मन',
        'en_AU' => 'ऑस्ट्रेलियाई अंग्रेज़ी',
        'en_CA' => 'कनाडाई अंग्रेज़ी',
        'en_GB' => 'ब्रिटिश अंग्रेज़ी',
        'en_US' => 'अमेरिकी अंग्रेज़ी',
        'es_419' => 'लैटिन अमेरिकी स्पेनिश',
        'es_ES' => 'यूरोपीय स्पेनिश',
        'es_MX' => 'मैक्सिकन स्पेनिश',
        'fa_AF' => 'दारी',
        'fr_CA' => 'कनाडाई फ़्रेंच',
        'fr_CH' => 'स्विस फ़्रेंच',
        'hi_Latn' => 'हिन्दी (लैटिन)',
        'nds_NL' => 'निचली सैक्सन',
        'nl_BE' => 'फ़्लेमिश',
        'pt_BR' => 'ब्राज़ीली पुर्तगाली',
        'pt_PT' => 'यूरोपीय पुर्तगाली',
        'ro_MD' => 'मोलडावियन',
        'sw_CD' => 'कांगो स्वाहिली',
        'zh_Hans' => 'सरलीकृत चीनी',
        'zh_Hant' => 'पारंपरिक चीनी',
    ],
];
